#!/bin/sh
#
# check_unique_users - Nagios plugin, checks the #users on the system (not the #terminals)
# by Michael Tosch

set -f
PATH=/bin:/usr/bin:/usr/sbin:/sbin:/usr/ucb
export PATH

print_usage(){
  echo "Usage: $0 [-w <integer>] [-c <integer>]"
}

checkint(){
  case $1 in
  *[!0-9]*|"") echo "$0: '$1' is not an integer"; exit 3;;
  esac
}

#defaults
warn=30000
crit=30000

#get args
while [ -n "$1" ]
do
  case $1 in
  -c) crit=$2; shift 2;;
  -w) warn=$2; shift 2;;
  *-h*)
    echo "This plugin checks how many unique users are logged on.
"
    print_usage
    echo "
 -w : Warning level for users logged on
 -c : Critical level for users logged on"
    exit 3;;
  *) print_usage; exit 3;;
  esac
done

checkint "$warn"
checkint "$crit"

# Solaris zone awareness
if [ "`{ /sbin/zonename; } 2>/dev/null`" = "global" ]
then
  scope="-z global"
else
  scope="-e"
fi

# NX/Citrix and Gnome/Mate no longer support utmp/wtmp (who,w,users,finger,last)
# get root login with the utmp method
uroot=`users | awk '$1=="root" {s=1} END {print s+0}' RS=" "`
# exclude root from the ps method but add from the previous
unique=`UNIX95=1 ps $scope -o uid= -o tty= | awk '$1!=0 && $2~/[^?]/ && u[$1]++==0 {++sum} END {print sum+r}' r="$uroot"`

if [ $unique -ge $crit ]; then
  outcode="CRITICAL"
  exitcode=2
elif [ $unique -ge $warn ]; then
  outcode="WARNING"
  exitcode=1
else
  outcode="OK"
  exitcode=0
fi

echo "${outcode}: $unique users are logged on | users=$unique"
exit $exitcode

